# coding: utf-8

"""
    Mentortools Static Server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.1.6
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest
import datetime

from static_server_connector.models.domain_migrate import DomainMigrate  # noqa: E501

class TestDomainMigrate(unittest.TestCase):
    """DomainMigrate unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> DomainMigrate:
        """Test DomainMigrate
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `DomainMigrate`
        """
        model = DomainMigrate()  # noqa: E501
        if include_optional:
            return DomainMigrate(
                domain_switches = [
                    static_server_connector.models.domain_switch.DomainSwitch(
                        old_domain = '', 
                        new_domain = '', )
                    ],
                new_domains = [
                    static_server_connector.models.domain_new.DomainNew(
                        from_domain = '', 
                        new_domain = '', )
                    ],
                remove_domains = [
                    ''
                    ]
            )
        else:
            return DomainMigrate(
                domain_switches = [
                    static_server_connector.models.domain_switch.DomainSwitch(
                        old_domain = '', 
                        new_domain = '', )
                    ],
                new_domains = [
                    static_server_connector.models.domain_new.DomainNew(
                        from_domain = '', 
                        new_domain = '', )
                    ],
                remove_domains = [
                    ''
                    ],
        )
        """

    def testDomainMigrate(self):
        """Test DomainMigrate"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Mentortools Static Server

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

    The version of the OpenAPI document: 1.1.6
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import re  # noqa: F401
import io
import warnings

from pydantic import validate_arguments, ValidationError
from typing import overload, Optional, Union, Awaitable

from typing_extensions import Annotated
from pydantic import Field, StrictBytes, StrictStr

from typing import Union

from static_server_connector.models.api_response_wrapper_boolean import ApiResponseWrapperBoolean
from static_server_connector.models.api_response_wrapper_font_upload_response import ApiResponseWrapperFontUploadResponse
from static_server_connector.models.domain_migrate import DomainMigrate
from static_server_connector.models.page_publish import PagePublish
from static_server_connector.models.page_unpublish import PageUnpublish
from static_server_connector.models.switch_desin_request import SwitchDesinRequest

from static_server_connector.api_client import ApiClient
from static_server_connector.api_response import ApiResponse
from static_server_connector.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class DefaultApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client

    @validate_arguments
    async def design_get(self, **kwargs) -> ApiResponseWrapperBoolean:  # noqa: E501
        """design_get  # noqa: E501


        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ApiResponseWrapperBoolean
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the design_get_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return await self.design_get_with_http_info(**kwargs)  # noqa: E501

    @validate_arguments
    async def design_get_with_http_info(self, **kwargs) -> ApiResponse:  # noqa: E501
        """design_get  # noqa: E501


        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ApiResponseWrapperBoolean, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
        ]
        _all_params.extend(
            [
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method design_get" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/json; charset=utf-8'])  # noqa: E501

        # authentication setting
        _auth_settings = []  # noqa: E501

        _response_types_map = {
            '200': "ApiResponseWrapperBoolean",
            '400': "ApiResponseWrapperBoolean",
            '409': "ApiResponseWrapperBoolean",
            '403': "ApiResponseWrapperBoolean",
            '404': "ApiResponseWrapperBoolean",
            '504': "ApiResponseWrapperBoolean",
            '500': "ApiResponseWrapperBoolean",
        }

        return await self.api_client.call_api(
            '/design', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    async def design_post(self, switch_desin_request : SwitchDesinRequest, **kwargs) -> ApiResponseWrapperBoolean:  # noqa: E501
        """design_post  # noqa: E501


        :param switch_desin_request: (required)
        :type switch_desin_request: SwitchDesinRequest
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ApiResponseWrapperBoolean
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the design_post_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return await self.design_post_with_http_info(switch_desin_request, **kwargs)  # noqa: E501

    @validate_arguments
    async def design_post_with_http_info(self, switch_desin_request : SwitchDesinRequest, **kwargs) -> ApiResponse:  # noqa: E501
        """design_post  # noqa: E501


        :param switch_desin_request: (required)
        :type switch_desin_request: SwitchDesinRequest
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ApiResponseWrapperBoolean, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'switch_desin_request'
        ]
        _all_params.extend(
            [
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method design_post" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['switch_desin_request'] is not None:
            _body_params = _params['switch_desin_request']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/json; charset=utf-8'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json; charset=utf-8']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['ServerNameSecurity']  # noqa: E501

        _response_types_map = {
            '200': "ApiResponseWrapperBoolean",
            '400': "ApiResponseWrapperBoolean",
            '409': "ApiResponseWrapperBoolean",
            '403': "ApiResponseWrapperBoolean",
            '404': "ApiResponseWrapperBoolean",
            '504': "ApiResponseWrapperBoolean",
            '500': "ApiResponseWrapperBoolean",
        }

        return await self.api_client.call_api(
            '/design', 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    async def domains_post(self, domain_migrate : DomainMigrate, **kwargs) -> ApiResponseWrapperBoolean:  # noqa: E501
        """domains_post  # noqa: E501


        :param domain_migrate: (required)
        :type domain_migrate: DomainMigrate
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ApiResponseWrapperBoolean
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the domains_post_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return await self.domains_post_with_http_info(domain_migrate, **kwargs)  # noqa: E501

    @validate_arguments
    async def domains_post_with_http_info(self, domain_migrate : DomainMigrate, **kwargs) -> ApiResponse:  # noqa: E501
        """domains_post  # noqa: E501


        :param domain_migrate: (required)
        :type domain_migrate: DomainMigrate
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ApiResponseWrapperBoolean, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'domain_migrate'
        ]
        _all_params.extend(
            [
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method domains_post" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['domain_migrate'] is not None:
            _body_params = _params['domain_migrate']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/json; charset=utf-8'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json; charset=utf-8']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['ServerNameSecurity']  # noqa: E501

        _response_types_map = {
            '200': "ApiResponseWrapperBoolean",
            '400': "ApiResponseWrapperBoolean",
            '409': "ApiResponseWrapperBoolean",
            '403': "ApiResponseWrapperBoolean",
            '404': "ApiResponseWrapperBoolean",
            '504': "ApiResponseWrapperBoolean",
            '500': "ApiResponseWrapperBoolean",
        }

        return await self.api_client.call_api(
            '/domains', 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    async def file_v1_publish_post(self, page_publish : PagePublish, **kwargs) -> ApiResponseWrapperBoolean:  # noqa: E501
        """file_v1_publish_post  # noqa: E501


        :param page_publish: (required)
        :type page_publish: PagePublish
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ApiResponseWrapperBoolean
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the file_v1_publish_post_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return await self.file_v1_publish_post_with_http_info(page_publish, **kwargs)  # noqa: E501

    @validate_arguments
    async def file_v1_publish_post_with_http_info(self, page_publish : PagePublish, **kwargs) -> ApiResponse:  # noqa: E501
        """file_v1_publish_post  # noqa: E501


        :param page_publish: (required)
        :type page_publish: PagePublish
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ApiResponseWrapperBoolean, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'page_publish'
        ]
        _all_params.extend(
            [
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method file_v1_publish_post" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['page_publish'] is not None:
            _body_params = _params['page_publish']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/json; charset=utf-8'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json; charset=utf-8']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['ServerNameSecurity']  # noqa: E501

        _response_types_map = {
            '200': "ApiResponseWrapperBoolean",
            '400': "ApiResponseWrapperBoolean",
            '409': "ApiResponseWrapperBoolean",
            '403': "ApiResponseWrapperBoolean",
            '404': "ApiResponseWrapperBoolean",
            '504': "ApiResponseWrapperBoolean",
            '500': "ApiResponseWrapperBoolean",
        }

        return await self.api_client.call_api(
            '/file/v1/publish', 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    async def file_v1_unpublish_post(self, page_unpublish : PageUnpublish, **kwargs) -> ApiResponseWrapperBoolean:  # noqa: E501
        """file_v1_unpublish_post  # noqa: E501


        :param page_unpublish: (required)
        :type page_unpublish: PageUnpublish
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ApiResponseWrapperBoolean
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the file_v1_unpublish_post_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return await self.file_v1_unpublish_post_with_http_info(page_unpublish, **kwargs)  # noqa: E501

    @validate_arguments
    async def file_v1_unpublish_post_with_http_info(self, page_unpublish : PageUnpublish, **kwargs) -> ApiResponse:  # noqa: E501
        """file_v1_unpublish_post  # noqa: E501


        :param page_unpublish: (required)
        :type page_unpublish: PageUnpublish
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ApiResponseWrapperBoolean, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'page_unpublish'
        ]
        _all_params.extend(
            [
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method file_v1_unpublish_post" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        if _params['page_unpublish'] is not None:
            _body_params = _params['page_unpublish']

        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/json; charset=utf-8'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['application/json; charset=utf-8']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['ServerNameSecurity']  # noqa: E501

        _response_types_map = {
            '200': "ApiResponseWrapperBoolean",
            '400': "ApiResponseWrapperBoolean",
            '409': "ApiResponseWrapperBoolean",
            '403': "ApiResponseWrapperBoolean",
            '404': "ApiResponseWrapperBoolean",
            '504': "ApiResponseWrapperBoolean",
            '500': "ApiResponseWrapperBoolean",
        }

        return await self.api_client.call_api(
            '/file/v1/unpublish', 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    async def fonts_v1_publish_post(self, portal_urls : Annotated[StrictStr, Field(..., description="Comma-separated list of portal URLs")], font_family : StrictStr, postscript_name : StrictStr, version : StrictStr, font_file : Annotated[Union[StrictBytes, StrictStr], Field(..., description="Font file (ttf, otf, woff, woff2, eot)")], **kwargs) -> ApiResponseWrapperFontUploadResponse:  # noqa: E501
        """fonts_v1_publish_post  # noqa: E501


        :param portal_urls: Comma-separated list of portal URLs (required)
        :type portal_urls: str
        :param font_family: (required)
        :type font_family: str
        :param postscript_name: (required)
        :type postscript_name: str
        :param version: (required)
        :type version: str
        :param font_file: Font file (ttf, otf, woff, woff2, eot) (required)
        :type font_file: bytearray
        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: ApiResponseWrapperFontUploadResponse
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the fonts_v1_publish_post_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return await self.fonts_v1_publish_post_with_http_info(portal_urls, font_family, postscript_name, version, font_file, **kwargs)  # noqa: E501

    @validate_arguments
    async def fonts_v1_publish_post_with_http_info(self, portal_urls : Annotated[StrictStr, Field(..., description="Comma-separated list of portal URLs")], font_family : StrictStr, postscript_name : StrictStr, version : StrictStr, font_file : Annotated[Union[StrictBytes, StrictStr], Field(..., description="Font file (ttf, otf, woff, woff2, eot)")], **kwargs) -> ApiResponse:  # noqa: E501
        """fonts_v1_publish_post  # noqa: E501


        :param portal_urls: Comma-separated list of portal URLs (required)
        :type portal_urls: str
        :param font_family: (required)
        :type font_family: str
        :param postscript_name: (required)
        :type postscript_name: str
        :param version: (required)
        :type version: str
        :param font_file: Font file (ttf, otf, woff, woff2, eot) (required)
        :type font_file: bytearray
        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(ApiResponseWrapperFontUploadResponse, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
            'portal_urls',
            'font_family',
            'postscript_name',
            'version',
            'font_file'
        ]
        _all_params.extend(
            [
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method fonts_v1_publish_post" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        if _params['portal_urls'] is not None:
            _form_params.append(('portal_urls', _params['portal_urls']))

        if _params['font_family'] is not None:
            _form_params.append(('font_family', _params['font_family']))

        if _params['postscript_name'] is not None:
            _form_params.append(('postscript_name', _params['postscript_name']))

        if _params['version'] is not None:
            _form_params.append(('version', _params['version']))

        if _params['font_file'] is not None:
            _files['font_file'] = _params['font_file']

        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json', 'application/json; charset=utf-8'])  # noqa: E501

        # set the HTTP header `Content-Type`
        _content_types_list = _params.get('_content_type',
            self.api_client.select_header_content_type(
                ['multipart/form-data']))
        if _content_types_list:
                _header_params['Content-Type'] = _content_types_list

        # authentication setting
        _auth_settings = ['ServerNameSecurity']  # noqa: E501

        _response_types_map = {
            '200': "ApiResponseWrapperFontUploadResponse",
            '400': "ApiResponseWrapperFontUploadResponse",
            '409': "ApiResponseWrapperFontUploadResponse",
            '403': "ApiResponseWrapperFontUploadResponse",
            '404': "ApiResponseWrapperFontUploadResponse",
            '504': "ApiResponseWrapperFontUploadResponse",
            '500': "ApiResponseWrapperFontUploadResponse",
        }

        return await self.api_client.call_api(
            '/fonts/v1/publish', 'POST',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))

    @validate_arguments
    async def root_get(self, **kwargs) -> str:  # noqa: E501
        """root_get  # noqa: E501


        :param _request_timeout: timeout setting for this request.
               If one number provided, it will be total request
               timeout. It can also be a pair (tuple) of
               (connection, read) timeouts.
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: str
        """
        kwargs['_return_http_data_only'] = True
        if '_preload_content' in kwargs:
            message = "Error! Please call the root_get_with_http_info method with `_preload_content` instead and obtain raw data from ApiResponse.raw_data"  # noqa: E501
            raise ValueError(message)
        return await self.root_get_with_http_info(**kwargs)  # noqa: E501

    @validate_arguments
    async def root_get_with_http_info(self, **kwargs) -> ApiResponse:  # noqa: E501
        """root_get  # noqa: E501


        :param _preload_content: if False, the ApiResponse.data will
                                 be set to none and raw_data will store the
                                 HTTP response body without reading/decoding.
                                 Default is True.
        :type _preload_content: bool, optional
        :param _return_http_data_only: response data instead of ApiResponse
                                       object with status code, headers, etc
        :type _return_http_data_only: bool, optional
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the authentication
                              in the spec for a single request.
        :type _request_auth: dict, optional
        :type _content_type: string, optional: force content-type for the request
        :return: Returns the result object.
                 If the method is called asynchronously,
                 returns the request thread.
        :rtype: tuple(str, status_code(int), headers(HTTPHeaderDict))
        """

        _params = locals()

        _all_params = [
        ]
        _all_params.extend(
            [
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout',
                '_request_auth',
                '_content_type',
                '_headers'
            ]
        )

        # validate the arguments
        for _key, _val in _params['kwargs'].items():
            if _key not in _all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method root_get" % _key
                )
            _params[_key] = _val
        del _params['kwargs']

        _collection_formats = {}

        # process the path parameters
        _path_params = {}

        # process the query parameters
        _query_params = []
        # process the header parameters
        _header_params = dict(_params.get('_headers', {}))
        # process the form parameters
        _form_params = []
        _files = {}
        # process the body parameter
        _body_params = None
        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain; charset=utf-8'])  # noqa: E501

        # authentication setting
        _auth_settings = []  # noqa: E501

        _response_types_map = {
            '200': "str",
        }

        return await self.api_client.call_api(
            '/', 'GET',
            _path_params,
            _query_params,
            _header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            response_types_map=_response_types_map,
            auth_settings=_auth_settings,
            _return_http_data_only=_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=_params.get('_preload_content', True),
            _request_timeout=_params.get('_request_timeout'),
            collection_formats=_collection_formats,
            _request_auth=_params.get('_request_auth'))
